For more details see ?peRspective or Perspective API documentation
unnest_scores(Output, score_model, score_sentences, text)comes out of the GET call.
Specify what model do you want to use (for example TOXICITY and/or SEVERE_TOXICITY). Specify a character vector if you want more than one score. See peRspective::prsp_models.
A boolean value that indicates if the request should return spans that describe the scores for each part of the text (currently done at per sentence level). Defaults to FALSE.
a character string.
a tibble